Interface: ChartConfiguration | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ChartConfiguration<TType, TData, TLabel>

## # Type parameters

Name | Type
--- | ---
`TType` | extends `ChartType` = `ChartType`
`TData` | `DefaultDataPoint`<`TType`>
`TLabel` | `unknown`

## # Properties

### # data

• data: `ChartData`<`TType`, `TData`, `TLabel`>

#### # Defined in

index.esm.d.ts:3702
(opens new window)

### # options

• `Optional` options: `DeepPartial`<`CoreChartOptions`<`TType`> & `ElementChartOptions`<`TType`> & `PluginChartOptions`<`TType`> & `DatasetChartOptions`<`TType`> & `ScaleChartOptions`<`TType`> & `ChartTypeRegistry`[`TType`][`"chartOptions"`]>

#### # Defined in

index.esm.d.ts:3703
(opens new window)

### # plugins

• `Optional` plugins: `Plugin`<`TType`, `AnyObject`>[]

#### # Defined in

index.esm.d.ts:3704
(opens new window)

### # type

• type: `TType`

#### # Defined in

index.esm.d.ts:3701
(opens new window)